all: InterestHeader and ContentObjectHeader refactoring to Interest and ContentObject

refs #29
diff --git a/disabled/ccnb-parser/visitors/interest-visitor.h b/disabled/ccnb-parser/visitors/interest-visitor.h
index f78d07f..38a969d 100644
--- a/disabled/ccnb-parser/visitors/interest-visitor.h
+++ b/disabled/ccnb-parser/visitors/interest-visitor.h
@@ -29,11 +29,11 @@
 
 /**
  * \ingroup ccnx-ccnb
  * \brief Visitor that fills fields in CcnxInterestHeader
  *
  * Usage example:
  * \code
- *   Ptr<CcnxInterestHeader> header = Create<CcnxInterestHeader> ();
+ *   Ptr<CcnxInterest> header = Create<CcnxInterest> ();
  *   Ptr<CcnbParser::Block> root = CcnbParser::Block::ParseBlock (i);
  *   InterestVisitor visitor;
  *   root->accept (visitor, *header); 
@@ -42,7 +42,7 @@
 class InterestVisitor : public VoidDepthFirstVisitor
 {
 public:
-  virtual void visit (Dtag &n, boost::any param/*should be CcnxInterestHeader* */);
+  virtual void visit (Dtag &n, boost::any param/*should be CcnxInterest* */);
 };
 
 } // namespace CcnbParser
@@ -29,11 +29,11 @@
 /**
  * \ingroup ccnx-ccnb
- * \brief Visitor that fills fields in CcnxInterestHeader
+ * \brief Visitor that fills fields in CcnxInterest
  *
  * Usage example: